@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backend.py 10410 2017-10-24 11:52:16Z David $
+# $Id: __init__.py 11172 2018-07-16 09:31:00Z Lavender $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: David $
-# $Date: 2017-10-24 19:52:16 +0800 (Tue, 24 Oct 2017) $
-# $Revision: 10410 $
+# $Author: Lavender $
+# $Date: 2018-07-16 17:31:00 +0800 (Mon, 16 Jul 2018) $
+# $Revision: 11172 $
 
 import logging
 import traceback
@@ -26,16 +26,9 @@ from django.conf import settings
 
 from Iuppiter.Encoding import utf8, _unicode
 from Iuppiter.Json import serializer
+from Iuppiter.Logging import createLogger
 
-logger = logging.getLogger('Newsletter')
-logger.setLevel(logging.DEBUG)
-handler = logging.StreamHandler()
-handler.setFormatter(
-    logging.Formatter("%(asctime)s - %(levelname)s - %(message)s"))
-logger.addHandler(handler)
-fileHandler = logging.FileHandler('Newsletter.log')
-fileHandler.setLevel(logging.WARNING)
-logger.addHandler(fileHandler)
+logger = createLogger(__name__, 'Newsletter.log')
 
 class EmailBackend(BaseEmailBackend):
 
@@ -47,11 +40,21 @@ class EmailBackend(BaseEmailBackend):
         super(EmailBackend, self).__init__(fail_silently=fail_silently)
 
         if not username:
-            username = settings.IUNO_CLOUD_NEWSLETTER_EMAIL_HOST_USER 
-            password = settings.IUNO_CLOUD_NEWSLETTER_EMAIL_HOST_PASSWORD
-            host = settings.IUNO_CLOUD_NEWSLETTER_EMAIL_HOST
-            use_tls = settings.IUNO_CLOUD_NEWSLETTER_EMAIL_USE_TLS
-            port = settings.IUNO_CLOUD_NEWSLETTER_EMAIL_PORT
+            try:
+                username = settings.IUNO_CLOUD_NEWSLETTER_EMAIL_HOST_USER 
+                password = settings.IUNO_CLOUD_NEWSLETTER_EMAIL_HOST_PASSWORD
+                host = settings.IUNO_CLOUD_NEWSLETTER_EMAIL_HOST
+                use_tls = settings.IUNO_CLOUD_NEWSLETTER_EMAIL_USE_TLS
+                port = settings.IUNO_CLOUD_NEWSLETTER_EMAIL_PORT
+
+                self.useSmtp = False
+            except Exception as e:
+                username = ''
+                password = ''
+                host = ''
+                use_tls = False
+                port = 443
+                self.useSmtp = True
 
         # username input:
         # admin$templates_shop$templates_shop_mails
@@ -121,7 +124,6 @@ class EmailBackend(BaseEmailBackend):
             result = self.parseResult(result)
             return result['token']
         except Exception as e:
-            logger.error("No JSON object could be decoded: %s" % link)
             raise
 
     def send_messages(self, email_messages):
@@ -131,6 +133,12 @@ class EmailBackend(BaseEmailBackend):
         @param email_messages Email messages.
         """
         try:
+            if self.useSmtp:
+                raise RuntimeError(
+                    "The project should set IUNO_CLOUD_NEWSLETTER_XXX"
+                    " in settings.py. see https://code.nuwainfo.com/"
+                    "trac/Mercurius/ticket/3123#comment:3")
+
             if not email_messages:
                 return
 
@@ -213,8 +221,8 @@ class EmailBackend(BaseEmailBackend):
                 except Exception as e:
                     raise
         except Exception as e:
-            errMsg = ("ERROR:\n%s\nUse SmtpEmailBackend to send email" % 
-                      traceback.print_exc())
+            errMsg = ("ERROR: %s\n%s\nUse SmtpEmailBackend to send email" % 
+                      (str(e), traceback.format_exc()))
             logger.error(errMsg)
             smtp = SmtpEmailBackend()
             return smtp.send_messages(email_messages)
\ No newline at end of file
