@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: start_project.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: start_project.py 11244 2018-10-10 15:19:58Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Date: 2018-10-10 23:19:58 +0800 (Wed, 10 Oct 2018) $
+# $Revision: 11244 $
 
 import os
 import sys
@@ -24,6 +24,8 @@ from django.core.management.base import BaseCommand, CommandError
 from django.template.loader import get_template
 from django.template import Context
 
+from Iuppiter.Encoding import utf8
+
 
 class Command(BaseCommand):
     help = 'Build django project with our setting and files.'
@@ -130,7 +132,7 @@ class Command(BaseCommand):
         content = content.strip() + '\n' + footer
 
         with open(settingPath, 'wb') as setting:
-            setting.write(six.b(content.replace('\r\n', '\n')))
+            setting.write(six.b(utf8(content.replace('\r\n', '\n'))))
 
         # Urls.py --------------------------------------------------------------
         with open(urlPath, 'r') as url:
