@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 11220 2018-09-02 04:29:45Z Lavender $
+# $Id: Util.py 11261 2018-11-15 19:36:42Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-09-02 13:29:45 +0900 (週日, 02 九月 2018) $
-# $Revision: 11220 $
+# $Date: 2018-11-16 03:36:42 +0800 (Fri, 16 Nov 2018) $
+# $Revision: 11261 $
 
 import sys
 import hashlib
@@ -116,4 +116,13 @@ class Payment(object):
 
     def __init__(self, formAction, formData, *args, **kwargs):
         self.formAction = formAction
-        self.formData = formData
\ No newline at end of file
+        self.formData = formData
+
+class ECPayShopShipment(object):
+    def __init__(self, hashKey, hashIv, sandbox, *args, **kwargs):
+        self.hashKey = hashKey
+        self.hashIv = hashIv
+        if sandbox:
+            self.ApiUrl = 'https://vendor-stage.ecpay.com.tw'
+        else:
+            self.ApiUrl = 'https://vendor.ecpay.com.tw'
\ No newline at end of file
