@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11248 2018-10-18 08:40:13Z Lavender $
+# $Id: __init__.py 11261 2018-11-15 19:36:42Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,20 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-10-18 17:40:13 +0900 (週四, 18 十月 2018) $
-# $Revision: 11248 $
+# $Date: 2018-11-16 03:36:42 +0800 (Fri, 16 Nov 2018) $
+# $Revision: 11261 $
 
 import os
 import sys
 import warnings
+import json
+import datetime
+import urllib
+import hashlib
 
+from collections import OrderedDict
+
+from Iuppiter.Encoding import utf8
 from Iuno import warnWithout, update, require
 from Iuppiter.DjangoUtil import (extendInstalledApps, 
                                  extendMiddlewareClasses, 
@@ -464,6 +471,8 @@ ALLPAY_SERVICE_URL = 'https://payment.allpay.com.tw/Cashier/AioCheckOut'
 SPGATEWAY = 'spgateway'
 ALLPAY = 'allpay'
 ECPAY = 'ecpay'
+ECPAY_MAP = 'ecpay_map'
+ECPAY_LOGISTIC = 'ecpay_logistic'
 CATHAYBK = 'cathaybk'
 
 class AllPay2(AllPay):
@@ -494,7 +503,8 @@ def buildAPIForm(submission, request, apiName):
     scheme = request.scheme
     domain = request.META['HTTP_HOST']
 
-    if not apiName in [SPGATEWAY, ALLPAY, ECPAY, CATHAYBK]:
+    if not apiName in [SPGATEWAY, ALLPAY, ECPAY, 
+                       CATHAYBK, ECPAY_LOGISTIC, ECPAY_MAP]:
         raise ValueError("Not pay api name: %s" % apiName)
 
     MERCHANT_TRADE_NO_LEN = 20
@@ -502,10 +512,18 @@ def buildAPIForm(submission, request, apiName):
     total = submission['order_total'].excl_tax
     basket = submission['basket']
     
+    from django.conf import settings
+    
     # item name
     itemName = utf8('')
     for index, line in enumerate(basket.all_lines()):
         product = line.product
+        
+        # this is for megaoil
+        if hasattr(settings, 'PRODUCT_UPC_PRICE_ADJUST'):
+            if product.upc in settings.PRODUCT_UPC_PRICE_ADJUST:
+                total = total + settings.PRODUCT_UPC_PRICE_ADJUST[product.upc]
+        
         productName = product.get_title()
         itemName += utf8(productName)
         
@@ -547,7 +565,7 @@ def buildAPIForm(submission, request, apiName):
             'ItemDesc': itemName.replace('#', '|'),
             'LoginType': 0,
             'CREDIT': 1,
-            'UNIONPAY': 1,
+            #'UNIONPAY': 1,
         }
 
         mpg = Pay2GoMPGAPI(
@@ -629,4 +647,117 @@ def buildAPIForm(submission, request, apiName):
 
         form = mpg.buildForm(data)
                                       
-        return form
\ No newline at end of file
+        return form
+
+    if apiName == ECPAY_MAP:
+        temp = get_template('shop/payment/EcpayMap.html')
+
+        if settings.ECPAY_SANDBOX_MODE:
+            apiUrl = "https://logistics-stage.ecpay.com.tw/Express/map"
+        else:
+            apiUrl = "https://logistics.ecpay.com.tw/Express/map"
+
+        if hasattr(settings, "ECPAY_API_LOGISTIC_SUB_TYPES"):
+            subTypes = settings.ECPAY_API_LOGISTIC_SUB_TYPES
+        else:
+            subTypes = {
+                "FAMI": u"全家便利商店",
+                "UNIMART": u"統一7-11超商" ,
+                "HILIFE": u"萊爾富",
+            }
+
+        data = {
+            'TradeDesc' : settings.OSCAR_SHOP_NAME, 
+            'Remark' : settings.OSCAR_SHOP_NAME,
+        }
+
+        context = Context({
+            'apiUrl': apiUrl,
+            'chantID': settings.ECPAY_API_MERCHANT_ID,
+            'subTypes': subTypes,
+            'returnUrl': returnUrl,
+            'extraData': json.dumps(
+                data, ensure_ascii=False, default=str).replace("\"", "&quot;"),
+        })
+        form = temp.render(context)
+                                      
+        return form
+
+    if apiName == ECPAY_LOGISTIC and request.POST:
+        storeId = request.POST.get("CVSStoreID")
+        subType = request.POST.get("LogisticsSubType")
+        extra = request.POST.get("ExtraData")
+
+        # 防呆
+        splitData = extra.split(",")
+        name = splitData[1][len("name="):]
+        phone = splitData[0][len("phone="):]
+
+        if settings.ECPAY_SANDBOX_MODE:
+            apiUrl = "https://logistics-stage.ecpay.com.tw/Express/Create"
+        else:
+            apiUrl = "https://logistics.ecpay.com.tw/Express/Create"
+
+        if hasattr(settings, "OSCAR_SHOP_NAME_FOR_ECPAY"):
+            shopName = settings.OSCAR_SHOP_NAME_FOR_ECPAY
+        else:
+            shopName = settings.OSCAR_SHOP_NAME
+
+        if hasattr(settings, "OSCAR_SHOP_PHONE"):
+            shopPhone = settings.OSCAR_SHOP_PHONE 
+        else:
+            shopPhone = ''
+
+        data = {
+            "MerchantID": settings.ECPAY_API_MERCHANT_ID,
+            "MerchantTradeNo": merchantTradeNo,
+            "MerchantTradeDate": datetime.datetime.now().strftime(
+                                    "%Y/%m/%d %H:%M:%S"),
+
+            "LogisticsType": "CVS",
+            "LogisticsSubType": subType,
+            "IsCollection": "Y",
+            "ReceiverStoreID": storeId,
+            
+            "GoodsAmount": int(total),
+            "CollectionAmount": int(total),
+            "GoodsName": itemName.replace("#", ' ').decode('utf8'),
+            
+            # 必須 len(SendName) <= 10 個字元 
+            "SenderName": shopName,
+            "SenderCellPhone": shopPhone,
+            "ReceiverName": name, 
+            "ReceiverCellPhone": phone, 
+            
+            "ServerReplyURL": "http://127.0.0.1:8000/posttest/", # 隨時接訂單資訊的 URL
+            "ClientReplyURL": returnUrl,               
+        }
+        
+        data = OrderedDict(data)
+        data = OrderedDict(sorted(data.iteritems()))
+
+        orderedDict = OrderedDict()
+        orderedDict['HashKey'] = settings.ECPAY_API_HASH_KEY
+        for field in data:
+            orderedDict[field] = data[field]
+
+        orderedDict['HashIV'] = settings.ECPAY_API_HASH_IV
+
+        dataList = []
+        for k, v in orderedDict.items():
+            dataList.append("%s=%s" % (k, v))
+        dataStr = u"&".join(dataList)
+
+        encodeStr = urllib.urlencode({'data': utf8(dataStr),})[5:]
+        checkValue = hashlib.md5(encodeStr.lower()).hexdigest().upper()
+        data["CheckMacValue"] = checkValue
+
+        temp = get_template('shop/payment/EcpayLogistic.html')
+        context = Context({
+            'apiUrl': apiUrl,
+            'data': data,
+        })
+        form = temp.render(context)
+
+        return form
+    return None
\ No newline at end of file
