@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11223 2018-09-09 07:48:50Z Lavender $
+# $Id: views.py 11261 2018-11-15 19:36:42Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,15 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-09-09 16:48:50 +0900 (週日, 09 九月 2018) $
-# $Revision: 11223 $ 
+# $Date: 2018-11-16 03:36:42 +0800 (Fri, 16 Nov 2018) $
+# $Revision: 11261 $ 
 
 import json
 import logging
 import hashlib
 
 from lxml import etree
+from django.shortcuts import render
 from django.views.decorators.csrf import csrf_exempt
 from django.utils.decorators import method_decorator
 from django.shortcuts import redirect, get_object_or_404
@@ -58,6 +59,8 @@ logger.addHandler(fileHandler)
 SPGATEWAY = 'spgateway'
 ALLPAY = 'allpay'
 ECPAY = 'ecpay'
+ECPAY_LOGISTIC = 'ecpay_logistic'
+ECPAY_MAP = 'ecpay_map'
 
 CATHAYBK_CREDIT = 'cathaybk-credit' # /cathaybk-credit/checkxml/
 CATHAYBK_CUP = 'cathaybk-cup' # /cathaybk-cup/checkxml/
@@ -96,6 +99,8 @@ def get_context_data(self, **kwargs):
     
     if ecpayEnable:
         kwargs['ecpay'] = buildAPIForm(submission, self.request, 'ecpay')
+        kwargs['ecpay_map'] = \
+            buildAPIForm(submission, self.request, 'ecpay_map')
     if allpayEnable:
         kwargs['allpay'] = buildAPIForm(submission, self.request, 'allpay')
     if spgatewayEnable:
@@ -281,7 +286,8 @@ class SuccessResponseView2(_PaymentDetailsView):
         self.apiName = kwargs['name']
         
         if not self.apiName in [
-            SPGATEWAY, ALLPAY, ECPAY, CATHAYBK_CREDIT, CATHAYBK_CUP]:
+            SPGATEWAY, ALLPAY, ECPAY, CATHAYBK_CREDIT, 
+            CATHAYBK_CUP, ECPAY_MAP, ECPAY_LOGISTIC]:
             raise ValueError("Not pay api name: %s" % apiName)
 
         try:
@@ -435,11 +441,50 @@ class SuccessResponseView2(_PaymentDetailsView):
 
                 self.tradeNo = cathaybkCreditTrade.tradeNo
                 self.tradeAmt = cathaybkCreditTrade.tradeAmt
+            elif self.apiName == ECPAY_MAP:
+                submission = super(
+                    SuccessResponseView2, self).build_submission(**kwargs)
+                form = buildAPIForm(submission, self.request, ECPAY_LOGISTIC)
+
+                if hasattr(settings, "ECPAY_API_LOGISTIC_SUB_TYPES"):
+                    subTypes = settings.ECPAY_API_LOGISTIC_SUB_TYPES
+                else:
+                    subTypes = {
+                        "FAMI": u"全家便利商店",
+                        "UNIMART": u"統一7-11超商" ,
+                        "HILIFE": u"萊爾富",
+                    }
+
+                data = {
+                    'storeName': self.request.POST.get('CVSStoreName'),
+                    'storeAddress': self.request.POST.get('CVSAddress'),
+                    'storeType': subTypes[
+                        self.request.POST.get('LogisticsSubType')],
+                    'storePhone': self.request.POST.get('CVSTelephone'),
+                    'form': form,
+                }
+                
+                return render(request, 'shop/payment/EcpayMapCheck.html', data)
+
+            elif self.apiName == ECPAY_LOGISTIC:
+                # data 
+                self.tradeNo = request.POST.get('AllPayLogisticsID')
+                self.tradeAmt = request.POST.get('GoodsAmount')
+
+                self.merchantTradeNo = request.POST.get('MerchantTradeNo')
+                index = self.merchantTradeNo.find('BASKETID')
+                self.basketId = int(self.merchantTradeNo[index + 8:])
+                
+                # record
+                for f in self.request.POST:
+                    print "%s: %s" % (f, self.request.POST[f])
+                
 
             return self.handle_place_order_submission(request)
         except Exception as e:
             # return msg
-
+            logger.error(str(e))
+            raise
             # if payment success
             msg1 = _("There was an except error in the payment."
                      " We have notified the administrator to deal with refund.")
@@ -505,25 +550,7 @@ class SuccessResponseView2(_PaymentDetailsView):
                         '%s API ERROR:\n%s\n%s' % (
                             self.apiName, request.POST, str(e)))
                     messages.error(self.request, msg2)
-            elif self.apiName == CATHAYBK_CREDIT:
-                if self.status == '0000':
-                    if not CathaybkCreditTrade.objects.filter(
-                        merchantTradeNo=self.merchantTradeNo).exists():
-                        logger.error(
-                            '%s API ERROR(this need to refund):\n%s\n%s' % (
-                                self.apiName, request.POST, str(e)))
-                        messages.error(self.request, msg1)
-                    else:
-                        logger.error(str(e))
-                        order = Order.objects.get(basket=request.basket)
-                        url = "%s?order_id=%d" % (
-                            reverse('checkout:thank-you'), order.id)
-                        return redirect(url)
-                else:
-                    logger.error(
-                        '%s API ERROR:\n%s\n%s' % (
-                            self.apiName, request.POST, str(e)))
-                    messages.error(self.request, msg2)
+            
 
             return redirect('checkout:payment-details')
         
