@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11172 2018-07-16 09:31:00Z Lavender $
+# $Id: __init__.py 11221 2018-09-02 04:41:14Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-07-16 18:31:00 +0900 (週一, 16 七月 2018) $
-# $Revision: 11172 $
+# $Date: 2018-09-02 12:41:14 +0800 (Sun, 02 Sep 2018) $
+# $Revision: 11221 $
 
 import os
 
@@ -26,7 +26,10 @@ if not settings.DEBUG:
         STATIC_DIR = settings.STATIC_ROOT
 else:
     if hasattr(settings, "STATICFILES_DIRS"):
-        STATIC_DIR = settings.STATICFILES_DIRS[0]
+        try:
+            STATIC_DIR = settings.STATICFILES_DIRS[0]
+        except Exception as e:
+            pass
         
 if not STATIC_DIR:
     STATIC_DIR = os.path.join(settings.BASE_DIR, "static")
